Skip to contents

`get_stroke()` returns the stroke number of input Chinese characters. Both Simplified Chinese and Traditional Chinese are supported.

Usage

stroke(char)

Arguments

char

A character vector of Chinese characters.

Value

An integer vector with the same length as input `char`. The returned integer vector is always named using input `char`.

Examples

stroke(c("千万", "鼠标"))
#> 千万 鼠标 
#>    6   22