`get_pinyin()` returns the pinyin of input Chinese characters. Both Simplified Chinese and Traditional Chinese are supported.
Value
A character vector with the same length as input `char`. The returned integer vector is always named using input `char`.
Examples
pinyin(c("平安", "行"))
#> 平安 行
#> "pínɡ ān" "xíng"