`sim2trad()` uses the dictionary `STCharacter.txt` distributed via [`OpenCC`](https://opencc.byvoid.com/) to convert Simplified Chinese to Traditional Chinese.
Arguments
- char
A character vector of Simplified Chinese characters.
- all
If `TRUE`, all possible match results of Traditional Chinese characters are returned. If `FALSE`, only the first match is returned. Default: `FALSE`.
Value
If `all` is `FALSE`, a character vector with the same length as input `char`. Otherwise, a list of character vector with the same length as input `char`. The returned character vector or list is always named using input `char`.